import babel from '@rollup/plugin-babel'
import resolve from '@rollup/plugin-node-resolve'
import commonjs from '@rollup/plugin-commonjs'
import json from '@rollup/plugin-json'
import replace from '@rollup/plugin-replace'
import builtins from 'builtin-modules'
import eslint from '@rollup/plugin-eslint'
import { terser } from 'rollup-plugin-terser'

const isWatch = process.env.ROLLUP_WATCH

export default {
  input: 'src/main.js',
  output: {
    file: 'dist/main.js',
    format: 'cjs'
  },
  external: builtins,
  plugins: [
    resolve({
      preferBuiltins: true
    }),	
    json(),
    commonjs({
      dynamicRequireTargets: [
        'node_modules/update-notifier/index.js'
      ]
    }),
    eslint({
      throwOnError: true,
      throwOnWarning: true,
      include: ['src/**'],
      exclude: ['node_modules/**']
    }),
    babel({
      exclude: 'node_modules/**',
      babelHelpers: 'runtime'
    }),
    replace({
      include: 'src/main.js',
      exclude: 'node_modules/**',
      NODE_ENV: JSON.stringify(process.env.NODE_ENV  || 'development')
    }),
    !isWatch && terser()
	]
}
